@@ -13,7 +13,8 @@ setMethod(
     y <- gmean(y)
     z <- gmean(z)
 
-    ternary_points(x = x, y = y, z = z, ...)
+    pt <- ternary_points(x = x, y = y, z = z, ...)
+    invisible(pt)
   }
 )
 
@@ -24,8 +25,9 @@ setMethod(
   f = "ternary_mean",
   signature = c(x = "ANY", y = "missing", z = "missing"),
   definition = function(x, ...) {
-    x <- grDevices::xyz.coords(x)
-    methods::callGeneric(x = x$x, y = x$y, z = x$z, ...)
+    xyz <- grDevices::xyz.coords(x)
+    pt <- methods::callGeneric(x = xyz$x, y = xyz$y, z = xyz$z, ...)
+    invisible(pt)
   }
 )
 
